@@ -40,7 +40,7 @@ from umbra.globals.runtimeGlobals import RuntimeGlobals
 #***	Module attributes.
 #**********************************************************************************************************************
 __author__ = "Thomas Mansencal"
-__copyright__ = "Copyright (C) 2008 - 2012 - Thomas Mansencal"
+__copyright__ = "Copyright (C) 2008 - 2013 - Thomas Mansencal"
 __license__ = "GPL V3.0 - http://www.gnu.org/licenses/"
 __maintainer__ = "Thomas Mansencal"
 __email__ = "thomas.mansencal@gmail.com"
@@ -758,9 +758,10 @@ class LocationsBrowser(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 		"""
 
 		activeIblSet = self.__inspector.activeIblSet
-		activeIblSet = activeIblSet and foundations.common.pathExists(activeIblSet.path) and \
-						activeIblSet or None
-		if activeIblSet:
+		if activeIblSet is None:
+			return False
+
+		if foundations.common.pathExists(activeIblSet.path):
 			return self.exploreDirectory(os.path.dirname(activeIblSet.path),
 										foundations.strings.encode(self.Custom_File_Browser_Path_lineEdit.text()))
 		else:
