@@ -72,8 +72,10 @@ umbra.globals.runtimeGlobals.RuntimeGlobals.__dict__.update(sibl_gui.globals.run
 
 for path in (os.path.join(sibl_gui.__path__[0], sibl_gui.globals.constants.Constants.resourcesDirectory),
 			os.path.join(os.getcwd(), sibl_gui.__name__, sibl_gui.globals.constants.Constants.resourcesDirectory)):
-	((os.path.exists(path) and not path in umbra.globals.runtimeGlobals.RuntimeGlobals.resourcesDirectories) and
-	umbra.globals.runtimeGlobals.RuntimeGlobals.resourcesDirectories.append(path))
+	path = os.path.normpath(path)
+	if os.path.exists(path):
+		path not in umbra.globals.runtimeGlobals.RuntimeGlobals.resourcesDirectories and \
+		umbra.globals.runtimeGlobals.RuntimeGlobals.resourcesDirectories.append(path)
 
 import foundations.globals.constants
 import manager.globals.constants
@@ -119,7 +121,7 @@ import umbra.ui.models
 #***	Module attributes.
 #**********************************************************************************************************************
 __author__ = "Thomas Mansencal"
-__copyright__ = "Copyright (C) 2008 - 2012 - Thomas Mansencal"
+__copyright__ = "Copyright (C) 2008 - 2013 - Thomas Mansencal"
 __license__ = "GPL V3.0 - http://www.gnu.org/licenses/"
 __maintainer__ = "Thomas Mansencal"
 __email__ = "thomas.mansencal@gmail.com"
